==> causeway-bom-2.1.0-source-release.zip: causeway-bom-2.1.0/viewers/wicket/model/src/main/java/org/apache/causeway/viewer/wicket/model/models/FormExecutorContext.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.apache.causeway.viewer.wicket.model.models;

import java.util.Optional;

import org.apache.causeway.applib.annotation.PromptStyle;
import org.apache.causeway.core.metamodel.context.HasMetaModelContext;
import org.apache.causeway.viewer.commons.model.object.HasUiParentObject;

public interface FormExecutorContext
extends
    HasUiParentObject<UiObjectWkt>,
    HasMetaModelContext {

    PromptStyle getPromptStyle();

    InlinePromptContext getInlinePromptContext();

    default boolean isWithinInlinePrompt() {
        return getPromptStyle().isInlineAny()
                && getInlinePromptContext() != null;
    }

    default Optional<ScalarParameterModel> getAssociatedParameter() {
        return Optional.empty();
    }

}

==> causeway-bom-3.4.0-source-release.zip: causeway-bom-3.4.0/viewers/wicket/model/src/main/java/org/apache/causeway/viewer/wicket/model/models/FormExecutorContext.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.apache.causeway.viewer.wicket.model.models;

import java.util.Optional;

import org.apache.causeway.applib.annotation.PromptStyle;
import org.apache.causeway.core.metamodel.context.HasMetaModelContext;
import org.apache.causeway.viewer.commons.model.object.HasUiParentObject;

public interface FormExecutorContext
extends
    HasUiParentObject<UiObjectWkt>,
    HasMetaModelContext {

    PromptStyle getPromptStyle();

    InlinePromptContext getInlinePromptContext();

    default boolean isWithinInlinePrompt() {
        return getPromptStyle().isInlineAny()
                && getInlinePromptContext() != null;
    }

    default Optional<ParameterModel> getAssociatedParameter() {
        return Optional.empty();
    }

}
